// -*-C++-*-
/*!
 * @file  ManipulatorCommonInterface_MiddleLevelSVC_impl.h
 * @brief Service implementation header of ManipulatorCommonInterface_MiddleLevel.idl
 *
 */

#include "ManipulatorCommonInterface_DataTypesSkel.h"
#include "BasicDataTypeSkel.h"

#include "ManipulatorCommonInterface_MiddleLevelSkel.h"

#ifndef MANIPULATORCOMMONINTERFACE_MIDDLELEVELSVC_IMPL_H
#define MANIPULATORCOMMONINTERFACE_MIDDLELEVELSVC_IMPL_H
 
/*!
 * @class ManipulatorCommonInterface_MiddleSVC_impl
 * Example class implementing IDL interface ManipulatorCommonInterface_Middle
 */
class ManipulatorCommonInterface_MiddleSVC_impl
 : public virtual POA_ManipulatorCommonInterface_Middle,
   public virtual PortableServer::RefCountServantBase
{
 private:
   // Make sure all instances are built on the heap by making the
   // destructor non-public
   //virtual ~ManipulatorCommonInterface_MiddleSVC_impl();

 public:
  /*!
   * @brief standard constructor
   */
   ManipulatorCommonInterface_MiddleSVC_impl();
  /*!
   * @brief destructor
   */
   virtual ~ManipulatorCommonInterface_MiddleSVC_impl();

   // attributes and operations
   RETURN_ID* closeGripper();
   RETURN_ID* getBaseOffset(HgMatrix offset);
   RETURN_ID* getFeedbackPosCartesian(CarPosWithElbow& pos);
   RETURN_ID* getMaxSpeedCartesian(CartesianSpeed& speed);
   RETURN_ID* getMaxSpeedJoint(DoubleSeq_out speed);
   RETURN_ID* getMinAccelTimeCartesian(CORBA::Double& aclTime);
   RETURN_ID* getMinAccelTimeJoint(CORBA::Double& aclTime);
   RETURN_ID* getSoftLimitCartesian(LimitValue& xLimit, LimitValue& yLimit, LimitValue& zLimit);
   RETURN_ID* moveGripper(ULONG angleRatio);
   RETURN_ID* moveLinearCartesianAbs(const CarPosWithElbow& carPoint);
   RETURN_ID* moveLinearCartesianRel(const CarPosWithElbow& carPoint);
   RETURN_ID* movePTPCartesianAbs(const CarPosWithElbow& carPoint);
   RETURN_ID* movePTPCartesianRel(const CarPosWithElbow& carPoint);
   RETURN_ID* movePTPJointAbs(const JointPos& jointPoints);
   RETURN_ID* movePTPJointRel(const JointPos& jointPoints);
   RETURN_ID* openGripper();
   RETURN_ID* pause();
   RETURN_ID* resume();
   RETURN_ID* stop();
   RETURN_ID* setAccelTimeCartesian(CORBA::Double aclTime);
   RETURN_ID* setAccelTimeJoint(CORBA::Double aclTime);
   RETURN_ID* setBaseOffset(const HgMatrix offset);
   RETURN_ID* setControlPointOffset(const HgMatrix offset);
   RETURN_ID* setMaxSpeedCartesian(const CartesianSpeed& speed);
   RETURN_ID* setMaxSpeedJoint(const DoubleSeq& speed);
   RETURN_ID* setMinAccelTimeCartesian(CORBA::Double aclTime);
   RETURN_ID* setMinAccelTimeJoint(CORBA::Double aclTime);
   RETURN_ID* setSoftLimitCartesian(const LimitValue& xLimit, const LimitValue& yLimit, const LimitValue& zLimit);
   RETURN_ID* setSpeedCartesian(ULONG spdRatio);
   RETURN_ID* setSpeedJoint(ULONG spdRatio);
   RETURN_ID* moveCircularCartesianAbs(const CarPosWithElbow& carPointR, const CarPosWithElbow& carPointT);
   RETURN_ID* moveCircularCartesianRel(const CarPosWithElbow& carPointR, const CarPosWithElbow& carPointT);
   RETURN_ID* setHome(const JointPos& jointPoint);
   RETURN_ID* getHome(JointPos_out jointPoint);
   RETURN_ID* goHome();

};



#endif // MANIPULATORCOMMONINTERFACE_MIDDLELEVELSVC_IMPL_H


